@@ -618,8 +618,12 @@ def batch_start(test_mode, script_name, secret_name='fbi_snowflake_creds', creds
         }
         if all(value is None for value in creds.values()):
             creds=settings.SNOWFLAKE_FPA
-            creds['usr'] = username
-            creds['pkb'] = pkb
+            usn_pkb = {
+                'usr': username,
+                'pkb': pkb
+            }
+            usn_pkb.update(creds)
+            creds=usn_pkb
             
     conn = get_snowflake_connection(**creds)
 
@@ -657,8 +661,12 @@ def batch_update(status, hash_id, secret_name='fbi_snowflake_creds', creds=None)
         }
         if all(value is None for value in creds.values()):
             creds=settings.SNOWFLAKE_FPA
-            creds['usr'] = username
-            creds['pkb'] = pkb
+            usn_pkb = {
+                'usr': username,
+                'pkb': pkb
+            }
+            usn_pkb.update(creds)
+            creds=usn_pkb
 
     conn = get_snowflake_connection(**creds)
     
